# API

```{eval-rst}
.. automodule:: maaspower

    ``maaspower``
    -----------------------------------
```

This is the internal API reference for maaspower

```{eval-rst}
.. data:: maaspower.__version__
    :type: str

    Version number as calculated by https://github.com/pypa/setuptools_scm
```
